@@ -78,7 +78,7 @@ class Databricks(object):
         
         body = {}
 
-        body["run_name"] = runName if runName != None else uuid.uuid4()
+        body["run_name"] = runName if runName != None else str(uuid.uuid4())
         body["existing_cluster_id"] = existingClusterId
         body["timeout_seconds"] = timeOut
         
