@@ -8,7 +8,7 @@ class BridgeTestCase(unittest.TestCase):
 
     #region Constructor
 
-    def __init__(self, fieldInfo: {(str, type)}, customEvents: [TestEvent], methodName: str = "runTest"):
+    def __init__(self, fieldInfo: [(str, type)], customEvents: [TestEvent], methodName: str = "runTest"):
         super(BridgeTestCase, self).__init__(methodName)
         self.__fieldInfo = fieldInfo
         self.__customEvents = customEvents
